@@ -450,11 +450,15 @@ Ext.define('MP.data.MetaData', {
                         idProperty: idField
                     });
 
+                    var remoteFilter = lup.remoteFilter===undefined ? true : lup.remoteFilter;
+                    var remoteSort = lup.remoteSort===undefined ? true : lup.remoteSort;
+
                     var lstore = Ext.create('Ext.data.Store', {
                         model: model,
                         pageSize: lup.pageSize || 0,
-                        remoteFilter: true,
-                        remoteSort: true,
+                        autoLoad: !remoteFilter || !remoteSort,
+                        remoteFilter: remoteFilter,
+                        remoteSort: remoteSort,
                         sorters: lup.sorters,
                         proxy: {
                             type: 'ajax',
