@@ -426,7 +426,19 @@ Ext.define("MP.data.Store", {
                     data[name] = null;
                 }
             }
-            return new me.model(data);
+
+            var record = new me.model(data);
+
+            // Do consider initial data as changes
+            if(initialdata) {
+                var modified = record.modified;
+
+                for(var fname in initialdata) {
+                    modified[fname] = undefined;
+                }
+            }
+
+            return record;
         } else {
             return false;
         }
